==> zio-aws-devopsguru_2.12-5.17.154.1-sources.jar: zio/aws/devopsguru/model/AnomalyReportedTimeRange.scala <==
package zio.aws.devopsguru.model
import zio.aws.devopsguru.model.primitives.Timestamp
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class AnomalyReportedTimeRange(
    openTime: Timestamp,
    closeTime: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devopsguru.model.AnomalyReportedTimeRange = {
    import AnomalyReportedTimeRange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devopsguru.model.AnomalyReportedTimeRange
      .builder()
      .openTime(Timestamp.unwrap(openTime): Instant)
      .optionallyWith(closeTime.map(value => Timestamp.unwrap(value): Instant))(
        _.closeTime
      )
      .build()
  }
  def asReadOnly: zio.aws.devopsguru.model.AnomalyReportedTimeRange.ReadOnly =
    zio.aws.devopsguru.model.AnomalyReportedTimeRange.wrap(buildAwsValue())
}
object AnomalyReportedTimeRange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devopsguru.model.AnomalyReportedTimeRange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devopsguru.model.AnomalyReportedTimeRange =
      zio.aws.devopsguru.model
        .AnomalyReportedTimeRange(openTime, closeTime.map(value => value))
    def openTime: Timestamp
    def closeTime: Option[Timestamp]
    def getOpenTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(openTime)
    def getCloseTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("closeTime", closeTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devopsguru.model.AnomalyReportedTimeRange
  ) extends zio.aws.devopsguru.model.AnomalyReportedTimeRange.ReadOnly {
    override val openTime: Timestamp =
      zio.aws.devopsguru.model.primitives.Timestamp(impl.openTime())
    override val closeTime: Option[Timestamp] = scala
      .Option(impl.closeTime())
      .map(value => zio.aws.devopsguru.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devopsguru.model.AnomalyReportedTimeRange
  ): zio.aws.devopsguru.model.AnomalyReportedTimeRange.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-devopsguru_2.13-5.17.195.2-sources.jar: zio/aws/devopsguru/model/AnomalyReportedTimeRange.scala <==
package zio.aws.devopsguru.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.devopsguru.model.primitives.Timestamp
import scala.jdk.CollectionConverters._
final case class AnomalyReportedTimeRange(
    openTime: Timestamp,
    closeTime: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devopsguru.model.AnomalyReportedTimeRange = {
    import AnomalyReportedTimeRange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devopsguru.model.AnomalyReportedTimeRange
      .builder()
      .openTime(Timestamp.unwrap(openTime): Instant)
      .optionallyWith(closeTime.map(value => Timestamp.unwrap(value): Instant))(
        _.closeTime
      )
      .build()
  }
  def asReadOnly: zio.aws.devopsguru.model.AnomalyReportedTimeRange.ReadOnly =
    zio.aws.devopsguru.model.AnomalyReportedTimeRange.wrap(buildAwsValue())
}
object AnomalyReportedTimeRange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devopsguru.model.AnomalyReportedTimeRange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devopsguru.model.AnomalyReportedTimeRange =
      zio.aws.devopsguru.model
        .AnomalyReportedTimeRange(openTime, closeTime.map(value => value))
    def openTime: Timestamp
    def closeTime: Optional[Timestamp]
    def getOpenTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(openTime)
    def getCloseTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("closeTime", closeTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devopsguru.model.AnomalyReportedTimeRange
  ) extends zio.aws.devopsguru.model.AnomalyReportedTimeRange.ReadOnly {
    override val openTime: Timestamp =
      zio.aws.devopsguru.model.primitives.Timestamp(impl.openTime())
    override val closeTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.closeTime())
      .map(value => zio.aws.devopsguru.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devopsguru.model.AnomalyReportedTimeRange
  ): zio.aws.devopsguru.model.AnomalyReportedTimeRange.ReadOnly = new Wrapper(
    impl
  )
}
